@@ -1,30 +1,27 @@
 package Tie::Redis;
-BEGIN {
-  $Tie::Redis::VERSION = '0.21';
+{
+  $Tie::Redis::VERSION = '0.23';
 }
 # ABSTRACT: Connect perl data structures to Redis
 use strict;
-use parent qw(AnyEvent::Redis);
 use Carp ();
 
+use Tie::Redis::Connection;
 use Tie::Redis::Hash;
 use Tie::Redis::List;
 use Tie::Redis::Scalar;
 
-{
-  # Work around bug in AnyEvent::Redis 0.22.
-  no strict 'refs';
-  *anyevent_read_type = *AnyEvent::Redis::anyevent_read_type;
-}
-
 sub TIEHASH {
   my($class, %args) = @_;
   my $serialize = delete $args{serialize};
+  
+  my $conn = Tie::Redis::Connection->new(%args);
+  Carp::croak "Unable to connect to Redis server: $!" unless $conn;
 
-  my $self = $class->AnyEvent::Redis::new(%args);
-  $self->{serialize} = $self->_serializer($serialize);
-
-  return $self;
+  bless {
+    _conn     => $conn,
+    serialize => $class->_serializer($serialize),
+  }, $class;
 }
 
 sub _serializer {
@@ -42,10 +39,13 @@ sub _serializer {
       \&Storaable::thaw
     ],
     msgpack => [
+      sub { require Data::MessagePack },
+      sub { unshift @_, "Data::MessagePack"; goto &Data::MessagePack::pack },
+      sub { unshift @_, "Data::MessagePack"; goto &Data::MessagePack::unpack }
     ],
   );
 
-  my $serializer = $serializers{$serialize} || [undef, (sub {
+  my $serializer = $serializers{$serialize || ''} || [undef, (sub {
     Carp::croak("No serializer specified for Tie::Redis; unable to handle nested structures");
   }) x 2];
 
@@ -62,19 +62,7 @@ sub _cmd {
     $args[0] = "$self->{prefix}$args[0]";
   }
 
-  if($self->{use_recv}) {
-    $self->$cmd(@args)->recv;
-  } else {
-    my $ok = 0;
-    my $ret;
-    $self->$cmd(@args, sub { $ok = 1; $ret = $_[0] });
-
-    # We need to block, but using ->recv won't work if the program is using
-    # ->recv at a higher level, so we do this slight hack.
-    # XXX: How to handle errors?
-    AnyEvent->one_event until $ok;
-    $ret;
-  }
+  $self->{_conn}->$cmd(@args);
 }
 
 sub STORE {
@@ -178,13 +166,17 @@ Tie::Redis - Connect perl data structures to Redis
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
  use Tie::Redis;
  tie my %r, "Tie::Redis";
 
+ $r{foo} = 42;
+
+ print $r{foo}; # 42, persistently
+
 =head1 DESCRIPTION
 
 This allows basic access to Redis from Perl using tie, so it looks just like a
@@ -194,11 +186,44 @@ B<Please> think carefully before using this, the tie interface has quite a
 performance overhead and the error handling is not that great. Using
 L<AnyEvent::Redis> or L<Redis> directly is recommended.
 
+=head2 General usage
+
+L<Tie::Redis> provides an interface to the top level Redis "hash table";
+depending on the type of key you access this then returns a value tied to
+L<Tie::Redis::Hash>, L<Tie::Redis::List>, L<Tie::Redis::Scalar> or a set type
+(unfortunately, these aren't yet implemented).
+
+If an error occurs these types will throw an exception, therefore you may want
+to surround your Redis accessing code with an C<eval> block (or use
+L<Try::Tiny>).
+
+=head2 Issues
+
+There are some cases where Redis and Perl types do not match, for example empty
+lists in Redis have a type of "none", therefore if you empty a list and then
+try to access it again it will no longer be an array reference.
+
+Autovivification currently doesn't correctly work, I believe some of this may
+be fixable but haven't yet fully investigated.
+
 =head1 SEE ALSO
 
-L<App::redisp> -- a redis shell in Perl and the main reason I wrote this
-module. L<AnyEvent::Redis> -- the API this uses to access Redis. L<Redis> --
-another Redis API.
+=over 4
+
+=item * L<App::redisp>
+
+A redis shell in Perl and the main reason I wrote this
+module.
+
+=item * L<Tie::Redis::Attributes>
+
+An experimental attribute based interface.
+
+=item * L<Redis>
+
+Another Redis API.
+
+=back
 
 =head1 AUTHOR
 
@@ -208,8 +233,9 @@ David Leadbeater <dgl@dgl.cx>
 
 This software is copyright (c) 2011 by David Leadbeater.
 
-This is free software; you can redistribute it and/or modify it under
-the terms of the Beerware license.
+This program is free software. It comes without any warranty, to the extent
+permitted by applicable law. You can redistribute it and/or modify it under the
+terms of the Beer-ware license revision 42.
 
 =cut
 
