@@ -1,7 +1,8 @@
 package Tie::Redis::Hash;
-BEGIN {
-  $Tie::Redis::Hash::VERSION = '0.21';
+{
+  $Tie::Redis::Hash::VERSION = '0.23';
 }
+# ABSTRACT: Connect a Redis hash to a Perl hash
 
 sub TIEHASH {
   my($class, %args) = @_;
@@ -65,28 +66,19 @@ sub SCALAR {
 1;
 
 
+
 __END__
 =pod
 
 =head1 NAME
 
-Tie::Redis::Hash
-
-=head1 VERSION
-
-version 0.21
-
-=head1 SYNOPSIS
-
-=cut
-
-=head1 NAME
-
 Tie::Redis::Hash - Connect a Redis hash to a Perl hash
 
 =head1 VERSION
 
-version 0.21
+version 0.23
+
+=head1 SYNOPSIS
 
 =head1 AUTHOR
 
@@ -96,8 +88,9 @@ David Leadbeater <dgl@dgl.cx>
 
 This software is copyright (c) 2011 by David Leadbeater.
 
-This is free software; you can redistribute it and/or modify it under
-the terms of the Beerware license.
+This program is free software. It comes without any warranty, to the extent
+permitted by applicable law. You can redistribute it and/or modify it under the
+terms of the Beer-ware license revision 42.
 
 =cut
 
