@@ -1,7 +1,8 @@
 package Tie::Redis::List;
-BEGIN {
-  $Tie::Redis::List::VERSION = '0.21';
+{
+  $Tie::Redis::List::VERSION = '0.23';
 }
+# ABSTRACT: Connect a Redis list to a Perl array
 
 sub TIEARRAY {
   my($class, %args) = @_;
@@ -45,6 +46,29 @@ sub STORE {
   }
 }
 
+sub POP {
+  my($self) = @_;
+  $self->_cmd("rpop");
+}
+
+sub SHIFT {
+  my($self) = @_;
+  $self->_cmd("lpop");
+}
+
+sub UNSHIFT {
+  my($self, $value) = @_;
+  $self->_cmd(lpush => $value);
+}
+
+sub SPLICE {
+  my($self, $offset, $length, @list) = @_;
+
+  my @items = $length == 0 ? () : $self->_cmd(lrange => $offset, $length - 1);
+  $self->_cmd(ltrim => $offset, $offset + $length - 1) if $length > 0;
+  # XXX
+}
+
 sub CLEAR {
   my($self) = @_;
   $self->_cmd("del");
@@ -58,23 +82,13 @@ __END__
 
 =head1 NAME
 
-Tie::Redis::List
-
-=head1 VERSION
-
-version 0.21
-
-=head1 SYNOPSIS
-
-=cut
-
-=head1 NAME
-
 Tie::Redis::List - Connect a Redis list to a Perl array
 
 =head1 VERSION
 
-version 0.21
+version 0.23
+
+=head1 SYNOPSIS
 
 =head1 AUTHOR
 
@@ -84,8 +98,9 @@ David Leadbeater <dgl@dgl.cx>
 
 This software is copyright (c) 2011 by David Leadbeater.
 
-This is free software; you can redistribute it and/or modify it under
-the terms of the Beerware license.
+This program is free software. It comes without any warranty, to the extent
+permitted by applicable law. You can redistribute it and/or modify it under the
+terms of the Beer-ware license revision 42.
 
 =cut
 
